Health region yearly male population estimates per age group
Source:R/regsaude_male_pop.R
regsaude_male_pop.RdThis function provides a tibble containing male population estimates for Brazilian health regions by age group.
R/regsaude_male_pop.R
regsaude_male_pop.RdThis function provides a tibble containing male population estimates for Brazilian health regions by age group.